appVersion property
App/build version reported on session start so a project targeting rule can
match appVersions. Null → not sent (no targeting on this attribute).
Implementation
final String? appVersion;
App/build version reported on session start so a project targeting rule can
match appVersions. Null → not sent (no targeting on this attribute).
final String? appVersion;