ThankYouCard class

Constructors

ThankYouCard({bool enabled = true, String title = 'Thank you!', String message = 'Your feedback has been submitted.', bool showButton = false, String? buttonText, String? buttonUrl})
const
ThankYouCard.fromJson(Map<String, Object?> j)
factory

Properties

buttonText String?
final
buttonUrl String?
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showButton bool
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited