DynamicVar class
A session-scoped key/value label used to segment sessions in reporting — e.g. an A/B variant, plan tier or store id. Use DynamicVar.fromString for text labels (auto-complete / regex filtering) and DynamicVar.fromInt for numbers (range filtering). Keys are capped at 50 chars, string values at 255 chars, int values at 0..2³²−1; blank keys are ignored when added.
Constructors
- DynamicVar.fromInt({required String key, required int value})
- DynamicVar.fromString({required String key, required String value})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
Empty when the supplied key was blank (such vars are ignored on add).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → Object
-
String(≤ 255 chars) orint(0..2³²−1).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited