StartConfig class
Start configuration for one-token onboarding.
Datasource/environment ids are public, source-scoped SDK tokens. They can write only to public SDK routes and are safe to embed in a mobile binary; they never authorize dashboard or administrative APIs.
Constructors
- StartConfig.withApiKey({required String id, AnalyticsOptions options = const AnalyticsOptions()})
-
factory
- StartConfig.withDatasourceId({required String id, AnalyticsOptions options = const AnalyticsOptions()})
-
factory
- StartConfig.withEnvironmentId({required String id, AnalyticsOptions options = const AnalyticsOptions()})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- kind → String
-
final
- options → AnalyticsOptions
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCxorbiConfig(
) → CxorbiConfig -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited